struct PerFileSink {
path: PathBuf,
results: Arc<Mutex<Vec<FileMatch>>>,
}Fields
path: PathBufresults: Arc<Mutex<Vec<FileMatch>>>Trait Implementations
Sourceimpl Sink for PerFileSink
impl Sink for PerFileSink
Sourcefn matched(
&mut self,
_Searcher: &Searcher,
Mat: &SinkMatch<'_>,
) -> Result<bool, Self::Error>
fn matched( &mut self, _Searcher: &Searcher, Mat: &SinkMatch<'_>, ) -> Result<bool, Self::Error>
This method is called whenever a match is found. Read more
fn context(
&mut self,
_searcher: &Searcher,
_context: &SinkContext<'_>,
) -> Result<bool, Self::Error>
fn context( &mut self, _searcher: &Searcher, _context: &SinkContext<'_>, ) -> Result<bool, Self::Error>
This method is called whenever a context line is found, and is optional
to implement. By default, it does nothing and returns
true. Read morefn context_break(&mut self, _searcher: &Searcher) -> Result<bool, Self::Error>
fn context_break(&mut self, _searcher: &Searcher) -> Result<bool, Self::Error>
This method is called whenever a break in contextual lines is found,
and is optional to implement. By default, it does nothing and returns
true. Read morefn binary_data(
&mut self,
_searcher: &Searcher,
_binary_byte_offset: u64,
) -> Result<bool, Self::Error>
fn binary_data( &mut self, _searcher: &Searcher, _binary_byte_offset: u64, ) -> Result<bool, Self::Error>
This method is called whenever binary detection is enabled and binary
data is found. If binary data is found, then this is called at least
once for the first occurrence with the absolute byte offset at which
the binary data begins. Read more